@@ -5,7 +5,7 @@
 /*  The code for generating a calendar.                        */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2018 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2020 by Dianne Skoll                    */
 /*                                                             */
 /***************************************************************/
 
@@ -785,6 +785,7 @@ static void GenerateCalEntries(int col)
     DestroyOmitContexts();
     DestroyVars(0);
     NumTriggered = 0;
+    ClearLastTriggers();
 
     r=IncludeFile(InitialFile);
     if (r) {
@@ -955,7 +956,7 @@ static int DoCalRem(ParsePtr p, int col)
 	return E_EOLN;
     }
     if (trig.typ == SAT_TYPE) {
-	r=DoSatRemind(&trig, p);
+	r=DoSatRemind(&trig, &tim, p);
 	if (r) {
 	    FreeTrig(&trig);
 	    if (r == E_EXPIRED) return OK;
@@ -999,7 +1000,7 @@ static int DoCalRem(ParsePtr p, int col)
 	}
     } else {
 	/* Calculate the trigger date */
-	jul = ComputeTrigger(trig.scanfrom, &trig, &r, 1);
+	jul = ComputeTrigger(trig.scanfrom, &trig, &tim, &r, 1);
 	if (r) {
 	    FreeTrig(&trig);
 	    return r;
