@@ -7,7 +7,7 @@
 /*  commands.                                                  */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2018 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2020 by Dianne Skoll                    */
 /*                                                             */
 /***************************************************************/
 
@@ -18,9 +18,9 @@
 
 #include <stdlib.h>
 
+#include "types.h"
 #include "globals.h"
 #include "err.h"
-#include "types.h"
 #include "protos.h"
 #include "expr.h"
 
@@ -34,6 +34,17 @@ static int ParseScanFrom (ParsePtr s, Trigger *t, int type);
 static int ParsePriority (ParsePtr s, Trigger *t);
 static int ParseUntil (ParsePtr s, Trigger *t);
 static int ShouldTriggerBasedOnWarn (Trigger *t, int jul, int *err);
+static int ComputeTrigDuration(TimeTrig *t);
+
+static int
+ComputeTrigDuration(TimeTrig *t)
+{
+    if (t->ttime == NO_TIME ||
+	t->duration == NO_TIME) {
+	return 0;
+    }
+    return (t->ttime + t->duration - 1) / 1440;
+}
 
 /***************************************************************/
 /*                                                             */
@@ -68,7 +79,7 @@ int DoRem(ParsePtr p)
     if (trig.typ == SAT_TYPE) {
 	PurgeEchoLine("%s\n", "#!P: Cannot purge SATISFY-type reminders");
 	PurgeEchoLine("%s\n", CurLine);
-	r=DoSatRemind(&trig, p);
+	r=DoSatRemind(&trig, &tim, p);
 	if (r) {
 	    FreeTrig(&trig);
 	    if (r == E_EXPIRED) return OK;
@@ -117,7 +128,7 @@ int DoRem(ParsePtr p)
 	}
     } else {
 	/* Calculate the trigger date */
-	jul = ComputeTrigger(trig.scanfrom, &trig, &r, 1);
+	jul = ComputeTrigger(trig.scanfrom, &trig, &tim, &r, 1);
 	if (r) {
 	    if (PurgeMode) {
 		PurgeEchoLine("%s: %s\n", "#!P! Problem calculating trigger date", ErrMsg[r]);
@@ -200,10 +211,14 @@ int ParseRem(ParsePtr s, Trigger *trig, TimeTrig *tim, int save_in_globals)
     trig->once = NO_ONCE;
     trig->typ = NO_TYPE;
     trig->scanfrom = NO_DATE;
+    trig->from = NO_DATE;
     trig->priority = DefaultPrio;
     trig->sched[0] = 0;
     trig->warn[0] = 0;
     trig->omitfunc[0] = 0;
+    trig->duration_days = 0;
+    trig->eventstart = NO_TIME;
+    trig->eventduration = NO_TIME;
     DBufInit(&(trig->tags));
     trig->passthru[0] = 0;
     tim->ttime = NO_TIME;
@@ -245,6 +260,7 @@ int ParseRem(ParsePtr s, Trigger *trig, TimeTrig *tim, int save_in_globals)
 	    tim->ttime = (tok.val % MINUTES_PER_DAY);
 	    if (save_in_globals) {
 		LastTriggerTime = tim->ttime;
+		SaveLastTimeTrig(tim);
 	    }
 	    break;
 
@@ -276,6 +292,7 @@ int ParseRem(ParsePtr s, Trigger *trig, TimeTrig *tim, int save_in_globals)
 	    DBufFree(&buf);
 	    r=ParseTimeTrig(s, tim, save_in_globals);
 	    if (r) return r;
+	    trig->duration_days = ComputeTrigDuration(tim);
 	    break;
 
 	case T_Scanfrom:
@@ -396,7 +413,15 @@ int ParseRem(ParsePtr s, Trigger *trig, TimeTrig *tim, int save_in_globals)
 	    switch(tok.type) {
 	    case T_Time:
 	    case T_LongTime:
-		tim->duration = tok.val;
+		if (tok.val != 0) {
+		    tim->duration = tok.val;
+		} else {
+		    tim->duration = NO_TIME;
+		}
+		if (save_in_globals) {
+		    SaveLastTimeTrig(tim);
+		}
+		trig->duration_days = ComputeTrigDuration(tim);
 		break;
 	    default:
 		return E_BAD_TIME;
@@ -468,6 +493,7 @@ static int ParseTimeTrig(ParsePtr s, TimeTrig *tim, int save_in_globals)
 	    /* Save trigger time in global variable */
 	    if (save_in_globals) {
 		LastTriggerTime = tim->ttime;
+		SaveLastTimeTrig(tim);
 	    }
 	    PushToken(DBufValue(&buf), s);
 	    DBufFree(&buf);
@@ -702,9 +728,12 @@ static int ParseScanFrom(ParsePtr s, Trigger *t, int type)
 	    }
 	    t->scanfrom = Julian(y, m, d);
 	    if (type == FROM_TYPE) {
+		t->from = t->scanfrom;
 		if (t->scanfrom < JulianToday) {
 		    t->scanfrom = JulianToday;
 		}
+	    } else {
+		t->from = NO_DATE;
 	    }
 
 	    PushToken(DBufValue(&buf), s);
@@ -1019,18 +1048,18 @@ int ShouldTriggerReminder(Trigger *t, TimeTrig *tim, int jul, int *err)
 /*  Do the "satisfying..." remind calculation.                 */
 /*                                                             */
 /***************************************************************/
-int DoSatRemind(Trigger *trig, ParsePtr p)
+int DoSatRemind(Trigger *trig, TimeTrig *tt, ParsePtr p)
 {
-    int iter, jul, r;
+    int iter, jul, r, start;
     Value v;
     char const *s;
     char const *t;
 
     t = p->pos;
     iter = 0;
-    jul = trig->scanfrom;
+    start = trig->scanfrom;
     while (iter++ < MaxSatIter) {
-	jul = ComputeTrigger(jul, trig, &r, 1);
+	jul = ComputeTriggerNoAdjustDuration(start, trig, tt, &r, 1);
 	if (r) {
 	    if (r == E_CANT_TRIG) return OK; else return r;
 	}
@@ -1042,14 +1071,42 @@ int DoSatRemind(Trigger *trig, ParsePtr p)
 	t = p->pos;
 	if (r) return r;
 	if (v.type != INT_TYPE && v.type != STR_TYPE) return E_BAD_TYPE;
-	if (v.type == INT_TYPE && v.v.val) return OK;
-	if (v.type == STR_TYPE && *v.v.str) return OK;
+	if ((v.type == INT_TYPE && v.v.val) ||
+	    (v.type == STR_TYPE && *v.v.str)) {
+	    AdjustTriggerForDuration(trig->scanfrom, jul, trig, tt, 1);
+	    if (DebugFlag & DB_PRTTRIG) {
+		int y, m, d;
+		FromJulian(LastTriggerDate, &y, &m, &d);
+		fprintf(ErrFp, "%s(%d): Trig(satisfied) = %s, %d %s, %d",
+			FileName, LineNo,
+			DayName[LastTriggerDate % 7],
+			d,
+			MonthName[m],
+			y);
+		if (tt->ttime != NO_TIME) {
+		    fprintf(ErrFp, " AT %02d:%02d",
+			    (tt->ttime / 60),
+			    (tt->ttime % 60));
+		    if (tt->duration != NO_TIME) {
+			fprintf(ErrFp, " DURATION %02d:%02d",
+				(tt->duration / 60),
+				(tt->duration % 60));
+		    }
+		}
+		fprintf(ErrFp, "\n");
+	    }
+	    return OK;
+	}
 	p->pos = s;
-	jul++;
+	if (jul+trig->duration_days < start) {
+	    start++;
+	} else {
+	    start = jul+trig->duration_days+1;
+	}
     }
     p->pos = t;
     LastTrigValid = 0;
-    return OK;
+    return E_CANT_TRIG;
 }
 
 /***************************************************************/
