@@ -7,7 +7,7 @@
 /*  MK_GLOBALS.  Also contains useful macro definitions.       */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2018 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2020 by Dianne Skoll                    */
 /*                                                             */
 /***************************************************************/
 
@@ -85,8 +85,10 @@ EXTERN  FILE *ErrFp;
 EXTERN  INIT(   FILE    *PurgeFP,  NULL);
 EXTERN  INIT(   int     NumIfs,    0);
 EXTERN  INIT(   unsigned int IfFlags,   0);
-EXTERN  INIT(   int     LastTriggerDate, 0);
 EXTERN  INIT(   int     LastTrigValid, 0);
+EXTERN  Trigger  LastTrigger;
+EXTERN  TimeTrig LastTimeTrig;
+EXTERN  INIT(   int     LastTriggerDate, 0);
 EXTERN  INIT(   int     LastTriggerTime, 0);
 EXTERN  INIT(   int     ShouldCache, 0);
 EXTERN  char const   *CurLine;
