@@ -6,7 +6,7 @@
 /*  routines, etc.                                             */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2018 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2020 by Dianne Skoll                    */
 /*                                                             */
 /***************************************************************/
 
@@ -63,14 +63,16 @@ int main(int argc, char *argv[])
     setlocale(LC_ALL, "");
 #endif
 
-/* The very first thing to do is to set up ErrFp to be stderr */
+    /* The very first thing to do is to set up ErrFp to be stderr */
     ErrFp = stderr;
 
-/* Set up global vars */
+    /* Set up global vars */
     ArgC = argc;
     ArgV = (char const **) argv;
 
     InitRemind(argc, (char const **) argv);
+    ClearLastTriggers();
+
     if (DoCalendar || (DoSimpleCalendar && (!NextMode || PsCal))) {
 	ProduceCalendar();
 	return 0;
@@ -129,6 +131,7 @@ int main(int argc, char *argv[])
 	    DestroyOmitContexts();
 	    DestroyVars(0);
 	    NumTriggered = 0;
+	    ClearLastTriggers();
 	    JulianToday++;
 	}
     }
@@ -799,8 +802,13 @@ int DoIfTrig(ParsePtr p)
     else {
 	if ( (r=ParseRem(p, &trig, &tim, 1)) ) return r;
 	if (trig.typ != NO_TYPE) return E_PARSE_ERR;
-	jul = ComputeTrigger(trig.scanfrom, &trig, &r, 1);
-	if (r) syndrome = IF_TRUE | BEFORE_ELSE;
+	jul = ComputeTrigger(trig.scanfrom, &trig, &tim, &r, 1);
+	if (r) {
+	    if (!Hush || r != E_RUN_DISABLED) {
+		Eprint("%s", ErrMsg[r]);
+	    }
+	    syndrome = IF_TRUE | BEFORE_ELSE;
+	}
 	else {
 	    if (ShouldTriggerReminder(&trig, &tim, jul, &err)) {
 		syndrome = IF_TRUE | BEFORE_ELSE;
@@ -1322,3 +1330,46 @@ FreeTrig(Trigger *t)
 {
     DBufFree(&(t->tags));
 }
+
+void
+ClearLastTriggers(void)
+{
+    LastTrigger.expired = 0;
+    LastTrigger.wd = NO_WD;
+    LastTrigger.d = NO_DAY;
+    LastTrigger.m = NO_MON;
+    LastTrigger.y = NO_YR;
+    LastTrigger.back = NO_BACK;
+    LastTrigger.delta = NO_DELTA;
+    LastTrigger.rep  = NO_REP;
+    LastTrigger.localomit = NO_WD;
+    LastTrigger.skip = NO_SKIP;
+    LastTrigger.until = NO_UNTIL;
+    LastTrigger.typ = NO_TYPE;
+    LastTrigger.once = NO_ONCE;
+    LastTrigger.scanfrom = NO_DATE;
+    LastTrigger.from = NO_DATE;
+    LastTrigger.priority = DefaultPrio;
+    LastTrigger.sched[0] = 0;
+    LastTrigger.warn[0] = 0;
+    LastTrigger.omitfunc[0] = 0;
+    LastTrigger.passthru[0] = 0;
+
+    LastTimeTrig.ttime = NO_TIME;
+    LastTimeTrig.delta = NO_DELTA;
+    LastTimeTrig.rep   = NO_REP;
+    LastTimeTrig.duration = NO_TIME;
+}
+
+void
+SaveLastTrigger(Trigger const *t)
+{
+    memcpy(&LastTrigger, t, sizeof(LastTrigger));
+    DBufInit(&(LastTrigger.tags));
+}
+
+void
+SaveLastTimeTrig(TimeTrig const *t)
+{
+    memcpy(&LastTimeTrig, t, sizeof(LastTimeTrig));
+}
