@@ -5,7 +5,7 @@
 /*  Function Prototypes.                                       */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2018 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2020 by Dianne Skoll                    */
 /*                                                             */
 /***************************************************************/
 
@@ -88,7 +88,10 @@ void HandleQueuedReminders (void);
 char const *FindInitialToken (Token *tok, char const *s);
 void FindToken (char const *s, Token *tok);
 void FindNumericToken (char const *s, Token *t);
-int ComputeTrigger (int today, Trigger *trig, int *err, int save_in_globals);
+int ComputeTrigger (int today, Trigger *trig, TimeTrig *tim, int *err, int save_in_globals);
+int ComputeTriggerNoAdjustDuration (int today, Trigger *trig, TimeTrig *tim, int *err, int save_in_globals);
+int AdjustTriggerForDuration(int today, int r, Trigger *trig, TimeTrig *tim, int save_in_globals);
+int ComputeScanStart(int today, Trigger *trig, TimeTrig *tt);
 char *StrnCpy (char *dest, char const *source, int n);
 int StrMatch (char const *s1, char const *s2, int n);
 int StrinCmp (char const *s1, char const *s2, int n);
@@ -105,7 +108,7 @@ void DumpVarTable (void);
 void DestroyVars (int all);
 int PreserveVar (char const *name);
 int DoPreserve  (Parser *p);
-int DoSatRemind (Trigger *trig, ParsePtr p);
+int DoSatRemind (Trigger *trig, TimeTrig *tt, ParsePtr p);
 int DoMsgCommand (char const *cmd, char const *msg);
 int ParseNonSpaceChar (ParsePtr p, int *err, int peek);
 unsigned int HashVal (char const *str);
@@ -142,3 +145,6 @@ void PurgeEchoLine(char const *fmt, ...);
 void FreeTrig(Trigger *t);
 void AppendTag(DynamicBuffer *buf, char const *s);
 char const *SynthesizeTag(void);
+void ClearLastTriggers(void);
+void SaveLastTrigger(Trigger const *t);
+void SaveLastTimeTrig(TimeTrig const *t);
