@@ -5,7 +5,7 @@
 /*  Type definitions all dumped here.                          */
 /*                                                             */
 /*  This file is part of REMIND.                               */
-/*  Copyright (C) 1992-2018 by Dianne Skoll                    */
+/*  Copyright (C) 1992-2020 by Dianne Skoll                    */
 /*                                                             */
 /***************************************************************/
 
@@ -68,7 +68,11 @@ typedef struct {
     int typ;
     int once;
     int scanfrom;
+    int from;
     int priority;
+    int duration_days;           /* Duration converted to days to search */
+    int eventstart;              /* Original event start (datetime) */
+    int eventduration;           /* Original event duration (minutes) */
     char sched[VAR_NAME_LEN+1];  /* Scheduling function */
     char warn[VAR_NAME_LEN+1];   /* Warning function    */
     char omitfunc[VAR_NAME_LEN+1]; /* OMITFUNC function */
@@ -87,16 +91,16 @@ typedef struct {
 
 /* The parse pointer */
 typedef struct {
-    char isnested;              /* Is it a nested expression? */
-    char allownested;
+    DynamicBuffer pushedToken;	/* Pushed-back token */
     char const *text;           /* Start of text */
     char const *pos;            /* Current position */
     char const *etext;          /* Substituted text */
     char const *epos;           /* Position in substituted text */
-    DynamicBuffer pushedToken;	/* Pushed-back token */
     char const *tokenPushed;	/* NULL if no pushed-back token */
-    char expr_happened;         /* Did we encounter an [expression] ? */
-    char nonconst_expr;         /* Did we encounter a non-constant [expression] ? */
+    unsigned char isnested;      /* Is it a nested expression? */
+    unsigned char allownested;
+    unsigned char expr_happened; /* Did we encounter an [expression] ? */
+    unsigned char nonconst_expr; /* Did we encounter a non-constant [expression] ? */
 } Parser;
 
 typedef Parser *ParsePtr;  /* Pointer to parser structure */
